%define lang_dom  libsmbios-2.4

Summary:       Libsmbios C/C++ shared libraries
Name:          libsmbios
Version:       2.4.3
Release:       6%{?dist}
License:       GPLv2+ or OSL 2.1
URL:           https://github.com/dell/libsmbios
Source0:       https://github.com/dell/libsmbios/archive/v%{version}/libsmbios-%{version}.tar.gz

BuildRequires: autoconf automake cppunit-devel doxygen gcc-c++
BuildRequires: gettext gettext-devel help2man libtool libxml2-devel
BuildRequires: make pkgconfig python3-devel strace valgrind

ExclusiveArch: x86_64

%description
This package provides a library and utilities that can be used by client
programs to get information from standard BIOS tables, such as the SMBIOS table.
This package provides the C-based libsmbios library, with a C interface.

%package -n python3-smbios
Summary:    Python interface to Libsmbios C library
Requires:   libsmbios = %{version}-%{release}
Requires:   python3

%description -n python3-smbios
This package provides a Python interface to libsmbios

%package -n smbios-utils
Summary: Meta-package that pulls in all smbios binaries and python scripts
Requires: smbios-utils-bin
Requires: smbios-utils-python

%description -n smbios-utils
This package provides a meta-package that pulls in the binary libsmbios executables
as well as the python executables.

%package -n smbios-utils-bin
Summary: Binary utilities that use libsmbios
Requires: libsmbios = %{version}-%{release}

%description -n smbios-utils-bin
This package provides tools which get BIOS information, such as System product name,
product id, service tag and asset tag.

%package -n smbios-utils-python
Summary: Python executables that use libsmbios
Requires: python3-smbios = %{version}-%{release}

%description -n smbios-utils-python
This package provides tools which get BIOS information, such as System product name,
product id, service tag and asset tag. Set service and asset tags on Dell machines.
Manipulate wireless cards/bluetooth on Dell laptops. Set BIOS password on select
Dell systems. Update BIOS on select Dell systems. Set LCD brightness on select Dell laptops.

%package -n libsmbios-devel
Summary: Development headers and archives
Requires: libsmbios = %{version}-%{release}

%description -n libsmbios-devel
This package provides a library and utilities that can be used by client
programs to get information from standard BIOS tables, such as the SMBIOS table.
This package provides the C-based libsmbios library, with a C interface.

%prep
%autosetup -n %{name}-%{version} -p1

find . -type d -exec chmod -f 755 {} \;
find doc src -type f -exec chmod -f 644 {} \;
chmod 755 src/cppunit/*.sh

mkdir _build
echo '../configure "$@"' > _build/configure
chmod +x _build/configure

%build
PACKAGE_VERSION=%{version} ./autogen.sh --no-configure
cd _build
%configure

mkdir -p out/libsmbios_c
make CFLAGS+="%{optflags} -Werror" %{?_smp_mflags}

%install
cd _build
TOPDIR=..
%make_install
rm -f %{buildroot}/%{_libdir}/lib*.{la,a}
find %{buildroot}/%{_includedir} out/libsmbios_c -exec touch -r $TOPDIR/configure.ac {} \;

mv out/libsmbios_c    out/libsmbios_c-%{_arch}

%py_byte_compile %{python3} %{buildroot}%{python3_sitearch}/

rename libsmbios.mo %{lang_dom}.mo $(find %{buildroot}/%{_datadir} -name libsmbios.mo)
%find_lang %{lang_dom}

%check
runtest() {
    mkdir _$1$2
    pushd _$1$2
    ../configure
    make -e $1 CFLAGS="$CFLAGS -DDEBUG_OUTPUT_ALL"
    touch -r ../configure.ac
    make -e $1
    popd
}

VALGRIND="strace -f" runtest check strace > /dev/null || echo FAILED strace check
runtest valgrind > /dev/null || echo FAILED valgrind check
runtest check > /dev/null || echo FAILED check


%files -f _build/%{lang_dom}.lang
%license COPYING-GPL COPYING-OSL
%{_libdir}/libsmbios_c.so.*

%files -n libsmbios-devel
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%doc README.md _build/out/libsmbios_c-%{_arch}
%{_includedir}/smbios_c
%{_libdir}/libsmbios_c.so
%{_libdir}/pkgconfig/*.pc

%files -n smbios-utils

%files -n smbios-utils-bin
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%{_sbindir}/smbios-state-byte-ctl
%{_mandir}/man?/smbios-state-byte-ctl.*
%{_sbindir}/smbios-get-ut-data
%{_mandir}/man?/smbios-get-ut-data.*
%{_sbindir}/smbios-upflag-ctl
%{_mandir}/man?/smbios-upflag-ctl.*
%{_sbindir}/smbios-sys-info-lite
%{_mandir}/man?/smbios-sys-info-lite.*

%files -n python3-smbios
%{python3_sitearch}/*

%files -n smbios-utils-python
%license src/bin/getopts_LICENSE.txt src/include/smbios_c/config/boost_LICENSE_1_0_txt
%dir %{_sysconfdir}/libsmbios
%config(noreplace) %{_sysconfdir}/libsmbios/*
%{_sbindir}/smbios-battery-ctl
%{_datadir}/smbios-utils
%{_mandir}/man?/smbios-battery-ctl.*
%{_sbindir}/smbios-sys-info
%{_mandir}/man?/smbios-sys-info.*
%{_sbindir}/smbios-token-ctl
%{_mandir}/man?/smbios-token-ctl.*
%{_sbindir}/smbios-passwd
%{_mandir}/man?/smbios-passwd.*
%{_sbindir}/smbios-wakeup-ctl
%{_mandir}/man?/smbios-wakeup-ctl.*
%{_sbindir}/smbios-wireless-ctl
%{_mandir}/man?/smbios-wireless-ctl.*
%{_sbindir}/smbios-lcd-brightness
%{_mandir}/man?/smbios-lcd-brightness.*
%{_sbindir}/smbios-keyboard-ctl
%{_mandir}/man?/smbios-keyboard-ctl.*
%{_sbindir}/smbios-thermal-ctl
%{_mandir}/man?/smbios-thermal-ctl.*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.3-6
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.3-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.3-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.3-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 16 2022 Shuo Wang <abushwang@tencent.com> - 2.4.3-1
- initial build
